/* GStreamer Video Render Switch
 * Copyright (C) 2010 Sami Kyöstilä <sami.kyostila@nokia.com>
 * Copyright (C) 2010 Miguel Verdu <miguel.verdu@nokia.com>
 *
 * videorenderswitch.h: video render mode switch interface design
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_VIDEO_RENDERSWITCH_H__
#define __GST_VIDEO_RENDERSWITCH_H__

#include <gst/gst.h>

G_BEGIN_DECLS

#define MEEGO_GST_TYPE_VIDEO_RENDERSWITCH \
  (meego_gst_video_renderswitch_get_type ())
#define MEEGO_GST_VIDEO_RENDERSWITCH(obj) \
  (GST_IMPLEMENTS_INTERFACE_CHECK_INSTANCE_CAST ((obj), MEEGO_GST_TYPE_VIDEO_RENDERSWITCH, \
                                                 MeegoGstVideoRenderSwitch))
#define MEEGO_GST_VIDEO_RENDERSWITCH_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), MEEGO_GST_TYPE_VIDEO_RENDERSWITCH, MeegoGstVideoRenderSwitchClass))
#define MEEGO_GST_IS_VIDEO_RENDERSWITCH(obj) \
  (GST_IMPLEMENTS_INTERFACE_CHECK_INSTANCE_TYPE ((obj), MEEGO_GST_TYPE_VIDEO_RENDERSWITCH))
#define MEEGO_GST_IS_VIDEO_RENDERSWITCH_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), MEEGO_GST_TYPE_VIDEO_RENDERSWITCH))
#define MEEGO_GST_VIDEO_RENDERSWITCH_GET_CLASS(inst) \
  (G_TYPE_INSTANCE_GET_INTERFACE ((inst), MEEGO_GST_TYPE_VIDEO_RENDERSWITCH, MeegoGstVideoRenderSwitchClass))
    

#define VIDEO_RENDERSWITCH_XOVERLAY_MODE            "x-overlay"
#define VIDEO_RENDERSWITCH_TEXTURE_STREAMING_MODE   "video-texture"

/**
 * MeegoGstVideoRenderSwitch:
 *
 * Opaque #MeegoGstVideoRenderSwitch data structure.
 */
typedef struct _MeegoGstVideoRenderSwitch MeegoGstVideoRenderSwitch;
typedef struct _MeegoGstVideoRenderSwitchClass MeegoGstVideoRenderSwitchClass;


/**
 * MeegoGstVideoRenderSwitchClass:
 * @klass: parent interface type.
 * @is_mode_supported: convenience method
 * #MeegoGstVideoRenderSwitch interface
 */

struct _MeegoGstVideoRenderSwitchClass {
  GTypeInterface klass;

  /* convenience method */  
  gboolean   (*is_mode_supported) (GList* supported, const gchar *mode);
  /*< private >*/
  gpointer                 _gst_reserved[GST_PADDING];
};

GType   meego_gst_video_renderswitch_get_type          (void);


G_END_DECLS

#endif /* __GST_VIDEO_RENDERSWITCH_H__ */
