/* GStreamer Video Texture Streaming
 * Copyright (C) 2010 Sami Kyöstilä <sami.kyostila@nokia.com>
 * Copyright (C) 2010 Miguel Verdu <miguel.verdu@nokia.com>
 *
 * videotexture.h: GL-based texture streaming interface design
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_VIDEO_TEXTURE_H__
#define __GST_VIDEO_TEXTURE_H__

#include <gst/gst.h>

G_BEGIN_DECLS

#define MEEGO_GST_TYPE_VIDEO_TEXTURE \
  (meego_gst_video_texture_get_type ())
#define MEEGO_GST_VIDEO_TEXTURE(obj) \
  (GST_IMPLEMENTS_INTERFACE_CHECK_INSTANCE_CAST ((obj), MEEGO_GST_TYPE_VIDEO_TEXTURE, \
                                                 MeegoGstVideoTexture))
#define MEEGO_GST_VIDEO_TEXTURE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), MEEGO_GST_TYPE_VIDEO_TEXTURE, MeegoGstVideoTextureClass))
#define MEEGO_GST_IS_VIDEO_TEXTURE(obj) \
  (GST_IMPLEMENTS_INTERFACE_CHECK_INSTANCE_TYPE ((obj), MEEGO_GST_TYPE_VIDEO_TEXTURE))
#define MEEGO_GST_IS_VIDEO_TEXTURE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), MEEGO_GST_TYPE_VIDEO_TEXTURE))
#define MEEGO_GST_VIDEO_TEXTURE_GET_CLASS(inst) \
  (G_TYPE_INSTANCE_GET_INTERFACE ((inst), MEEGO_GST_TYPE_VIDEO_TEXTURE, MeegoGstVideoTextureClass))
  
 
/**
 * MeegoGstVideoTexture:
 *
 * Opaque #MeegoGstVideoTexture data structure.
 */
typedef struct _MeegoGstVideoTexture MeegoGstVideoTexture;
typedef struct _MeegoGstVideoTextureClass MeegoGstVideoTextureClass;

/**
 * MeegoGstVideoTextureClass:
 * @klass: parent interface type.
 * @acquire_frame: virtual method to lock frame to be use for graphic rendering
 * @bind_frame: virtual method to bind a given frame to an OpenGL texture
 * @release_frame: virtual method to unlock a frame after it has been used.
 *
 * #MeegoGstVideoTexture interface
 */

struct _MeegoGstVideoTextureClass {
  GTypeInterface klass;

   /* interface methods */

  gboolean (*acquire_frame) (MeegoGstVideoTexture * vt, gint frame);
  gboolean (*bind_frame)    (MeegoGstVideoTexture * vt, gint target, gint frame);
  void     (*release_frame) (MeegoGstVideoTexture * vt, gint frame, gpointer sync);
  
    /*< private >*/
  gpointer                 _gst_reserved[GST_PADDING];
};

GType   meego_gst_video_texture_get_type          (void);

/* virtual class function wrappers */

gboolean meego_gst_video_texture_acquire_frame (MeegoGstVideoTexture * vt, gint frame);
gboolean meego_gst_video_texture_bind_frame    (MeegoGstVideoTexture * vt, gint target, gint frame);
void     meego_gst_video_texture_release_frame (MeegoGstVideoTexture * vt, gint frame, gpointer sync);

/* trigger signals */
void     meego_gst_video_texture_frame_ready (MeegoGstVideoTexture * vt, gint frame);

G_END_DECLS

#endif /* __GST_VIDEO_TEXTURE_H__ */
